@@ -40,10 +40,7 @@ using namespace hipsparse_test;
 template <typename T>
 void testing_bsr2csr_bad_arg(void)
 {
-#ifdef __HIP_PLATFORM_NVIDIA__
-    // do not test for bad args
-    return;
-#endif
+#if(!defined(CUDART_VERSION))
     int                  m            = 100;
     int                  n            = 100;
     int                  safe_size    = 100;
@@ -271,6 +268,7 @@ void testing_bsr2csr_bad_arg(void)
                                csr_row_ptr,
                                csr_col_ind);
     verify_hipsparse_status_invalid_size(status, "Error: block_dim is invalid");
+#endif
 }
 
 template <typename T>
@@ -375,14 +373,14 @@ hipsparseStatus_t testing_bsr2csr(Arguments argus)
                                    dcsr_row_ptr,
                                    dcsr_col_ind);
 
-        if(mb < 0 || nb < 0 || block_dim < 0)
+        if(mb < 0 || nb < 0 || block_dim <= 0)
         {
             verify_hipsparse_status_invalid_size(status,
-                                                 "Error: mb < 0 || nb < 0 || block_dim < 0");
+                                                 "Error: mb < 0 || nb < 0 || block_dim <= 0");
         }
         else
         {
-            verify_hipsparse_status_success(status, "mb >= 0 && nb >= 0 && block_dim >= 0");
+            verify_hipsparse_status_success(status, "mb >= 0 && nb >= 0 && block_dim > 0");
         }
 
         return HIPSPARSE_STATUS_SUCCESS;
