@@ -40,10 +40,7 @@ using namespace hipsparse_test;
 template <typename T>
 void testing_csr2bsr_bad_arg(void)
 {
-#ifdef __HIP_PLATFORM_NVIDIA__
-    // do not test for bad args
-    return;
-#endif
+#if(!defined(CUDART_VERSION))
     int                  m            = 100;
     int                  n            = 100;
     int                  safe_size    = 100;
@@ -395,6 +392,7 @@ void testing_csr2bsr_bad_arg(void)
                                bsr_row_ptr,
                                bsr_col_ind);
     verify_hipsparse_status_invalid_size(status, "Error: block_dim is invalid");
+#endif
 }
 
 template <typename T>
@@ -495,13 +493,13 @@ hipsparseStatus_t testing_csr2bsr(Arguments argus)
                                       dbsr_row_ptr,
                                       &bsr_nnzb);
 
-        if(m < 0 || n < 0 || block_dim < 0)
+        if(m < 0 || n < 0 || block_dim <= 0)
         {
-            verify_hipsparse_status_invalid_size(status, "Error: m < 0 || n < 0 || block_dim < 0");
+            verify_hipsparse_status_invalid_size(status, "Error: m < 0 || n < 0 || block_dim <= 0");
         }
         else
         {
-            verify_hipsparse_status_success(status, "m >= 0 && n >= 0 && block_dim >= 0");
+            verify_hipsparse_status_success(status, "m >= 0 && n >= 0 && block_dim > 0");
         }
 
         status = hipsparseXcsr2bsr(handle,
@@ -518,13 +516,13 @@ hipsparseStatus_t testing_csr2bsr(Arguments argus)
                                    dbsr_row_ptr,
                                    dbsr_col_ind);
 
-        if(m < 0 || n < 0 || block_dim < 0)
+        if(m < 0 || n < 0 || block_dim <= 0)
         {
-            verify_hipsparse_status_invalid_size(status, "Error: m < 0 || n < 0 || block_dim < 0");
+            verify_hipsparse_status_invalid_size(status, "Error: m < 0 || n < 0 || block_dim <= 0");
         }
         else
         {
-            verify_hipsparse_status_success(status, "m >= 0 && n >= 0 && block_dim >= 0");
+            verify_hipsparse_status_success(status, "m >= 0 && n >= 0 && block_dim > 0");
         }
 
         return HIPSPARSE_STATUS_SUCCESS;
