@@ -40,10 +40,7 @@ using namespace hipsparse_test;
 template <typename T>
 void testing_csr2csc_ex2_bad_arg(void)
 {
-#ifdef __HIP_PLATFORM_NVIDIA__
-    // do not test for bad args
-    return;
-#endif
+#if(!defined(CUDART_VERSION))
     int               m           = 100;
     int               n           = 100;
     int               nnz         = 100;
@@ -349,6 +346,7 @@ void testing_csr2csc_ex2_bad_arg(void)
                                      buffer_null);
         verify_hipsparse_status_invalid_pointer(status, "Error: buffer is nullptr");
     }
+#endif
 }
 
 template <typename T>
